==> lagrange-1.9.5.tar.gz: lagrange-1.9.5/AUTHORS.md <==
# Authors and Contributors

Lagrange was created by Jaakko Keränen (<jaakko.keranen@iki.fi>) in July 2020. The source code license is **BSD 2-Clause**. UI translations (_*.po_) are under **CC-BY-SA 4.0**.

Legend: `C` code, `T` translation

```
C  2665  Jaakko Keränen <jaakko.keranen@iki.fi>
CT   39  Nikolay Korotkiy <sikmir@gmail.com>
 T   39  Olga Smirnova <mistresssilvara@hotmail.com>
 T   28  Anna “CyberTailor” <cyber@sysrq.in>
 T   27  Alyssa Liddell <e-liss@tuta.io>
 T   25  Shibo Lyu <github@of.sb>
 T   22  Страхиња Радић <contact@strahinja.org>
 T   17  MCMic <come@chilliet.eu>
 T   15  Wally Hackenslacker <mastor89@protonmail.com>
 T   10  Tadeáš Erban <tadysekerbosek@gmail.com>
 T   10  Xosé M <correoxm@disroot.org>
 T    9  Aaron Fischer <mail@aaron-fischer.net>
 T    8  El Mau <public@correolibre.net>
 T    7  Waterrail <maksymiliankrol03@gmail.com>
 T    5  roy niang <roy@royniang.com>
 T    3  Alex Schroeder <alex@alexschroeder.ch>
 T    3  Botond Balázs <balazsbotond@gmail.com>
C     2  Alyssa Rosenzweig <alyssa@rosenzweig.io>
 T    2  Arns Udovič <zordsdavini@arns.lt>
C     2  Br0000k <77938600+Br0000k@users.noreply.github.com>
 T    2  Gabriel de Oliveira Ferreira Machado <goliv04053@tutanota.com>
C     2  Manos Pitsidianakis <el13635@mail.ntua.gr>
 T    2  methbkts <methbkts@gmail.com>
 T    2  tbodt <tblodt@icloud.com>
C     1  Adam Mizerski <adam@mizerski.pl>
C     1  Charles <charles@cdaniels.net>
C     1  Dario Vladovic <d.vladimyr@gmail.com>
C     1  David Gillies <dave.gillies@gmail.com>
 T    1  Emir <emir_sari@msn.com>
 T    1  Eric <spice2wolf@gmail.com>
 T    1  Marek Ľach <mareklachbc@tutanota.com>
C     1  Raph M <raph@raphm.com>
C     1  SolidHal <hal@halemmerich.com>
C     1  Thomas Adam <thomas.adam@smoothwall.net>
C     1  Waweic <waweic@activ.ism.rocks>
C     1  Waweic <waweic@protonmail.com>
C     1  Zach DeCook <zachdecook@librem.one>
C     1  zocker <zocker@10zen.eu>
```

This table of contributors has been extracted from Git history and is sorted by commit count.

==> lagrange-1.10.0.tar.gz: lagrange-1.10.0/AUTHORS.md <==
# Authors and Contributors

Lagrange was created by Jaakko Keränen (<jaakko.keranen@iki.fi>) in July 2020. The source code license is **BSD 2-Clause**. UI translations (_*.po_) are under **CC-BY-SA 4.0**.

Legend: `C` code, `T` translation

```
C  3009  Jaakko Keränen <jaakko.keranen@iki.fi>
CT   43  Nikolay Korotkiy <sikmir@gmail.com>
 T   42  Alyssa Liddell <e-liss@tuta.io>
 T   41  Olga Smirnova <mistresssilvara@hotmail.com>
 T   30  Anna “CyberTailor” <cyber@sysrq.in>
 T   27  Страхиња Радић <contact@strahinja.org>
 T   26  Shibo Lyu <github@of.sb>
 T   19  Wally Hackenslacker <mastor89@protonmail.com>
 T   18  MCMic <come@chilliet.eu>
 T   14  Xosé M <correoxm@disroot.org>
 T   13  Tadeáš Erban <tadysekerbosek@gmail.com>
 T    9  Aaron Fischer <mail@aaron-fischer.net>
 T    8  El Mau <public@correolibre.net>
 T    7  Waterrail <maksymiliankrol03@gmail.com>
 T    5  Emir <emir_sari@msn.com>
 T    5  roy niang <roy@royniang.com>
 T    3  Alex Schroeder <alex@alexschroeder.ch>
 T    3  Botond Balázs <balazsbotond@gmail.com>
C     2  Alyssa Rosenzweig <alyssa@rosenzweig.io>
 T    2  Andrij Mizyk <andmizyk@gmail.com>
 T    2  Arns Udovič <zordsdavini@arns.lt>
C     2  Br0000k <77938600+Br0000k@users.noreply.github.com>
 T    2  Gabriel de Oliveira Ferreira Machado <goliv04053@tutanota.com>
 T    2  Jop Vernooy <jop@jopv.net>
C     2  Manos Pitsidianakis <el13635@mail.ntua.gr>
 T    2  methbkts <methbkts@gmail.com>
 T    2  tbodt <tblodt@icloud.com>
C     1  Adam Mizerski <adam@mizerski.pl>
C     1  Charles <charles@cdaniels.net>
C     1  Dario Vladovic <d.vladimyr@gmail.com>
C     1  David Gillies <dave.gillies@gmail.com>
 T    1  Emir SARI <emir_sari@icloud.com>
 T    1  Eric <spice2wolf@gmail.com>
 T    1  Marek Ľach <mareklachbc@tutanota.com>
C     1  Raph M <raph@raphm.com>
C     1  SolidHal <hal@halemmerich.com>
C     1  Thomas Adam <thomas.adam@smoothwall.net>
 T    1  Timothée Goguely <timothee@goguely.com>
C     1  Waweic <waweic@activ.ism.rocks>
C     1  Waweic <waweic@protonmail.com>
C     1  Zach DeCook <zachdecook@librem.one>
C     1  jcromero <jcromero+github@disconfor.me>
C     1  zocker <zocker@10zen.eu>
```

This table of contributors has been extracted from Git history and is sorted by commit count.
